//
// Created by philipp on 08.05.18.
//

#ifndef PC_LOGGER_H
#define PC_LOGGER_H

#include <memory>
#include <NetworkingLib/Networking.h>
#include <NetworkingLib/ServiceClient.h>
#include "Message.h"
#include "Parser.h"
#include "StringService.h"

namespace message
{

class Client
    : public std::enable_shared_from_this<Client>
      , public networking::Busyable
{
private:
    struct PrivateTag
    {
    };

public:
    using Ptr = std::shared_ptr<Client>;
    using ServiceClient = networking::service::Client<StringService>;
    using OnMessageProcessedCallback = std::function<void(const Message & message)>;
    using OnRequestFinishedCallback = std::function<void(const networking::error::ErrorCode & error)>;

    static constexpr std::size_t MAX_MESSAGE_SIZE{1024};

    static Ptr create(networking::Networking & net, std::uint16_t port)
    { return std::make_shared<Client>(PrivateTag{}, net, port); }

    Client(PrivateTag, networking::Networking & net, std::uint16_t port);

    void requestMessages(const std::string & host,
                         const networking::time::Duration & timeout,
                         const Client::OnMessageProcessedCallback & onMessageProcessedCallback,
                         const Client::OnRequestFinishedCallback & onRequestFinishedCallback =
                         [](const auto & error) {});

    void stop();

private:
    struct AsyncState
    {
        using Ptr = std::shared_ptr<AsyncState>;

        AsyncState(Client::Ptr self,
                   const OnMessageProcessedCallback & onMessageProcessedCallback,
                   const OnRequestFinishedCallback & onRequestFinishedCallback)
            : lock(*self)
              , self(self)
              , onMessageProcessedCallback(onMessageProcessedCallback)
              , onRequestFinishedCallback(onRequestFinishedCallback)
        {}

        networking::BusyLock lock;
        Client::Ptr self;
        OnMessageProcessedCallback onMessageProcessedCallback;
        OnRequestFinishedCallback onRequestFinishedCallback;
    };

    networking::Networking & net;
    std::uint16_t port;
    ServiceClient::Ptr client;
    Parser parser;
};

}

#endif //PC_LOGGER_H
